@@ -116,6 +116,7 @@ pub mod position {
     use super::common::true_anomaly;
     use super::coordinate_transforms::euler_angle_transformations;
     use glam::f64::{DVec2, DVec3};
+    use glam::f32::Vec3;
 
     /// Position of a single celestial object relative to the sun.
     /// Can be used in conjuction with companion functions to place a twobody system relative to the sun.
@@ -138,6 +139,24 @@ pub mod position {
         DVec3::new(x, y, z)
     }
 
+    /// Same as [position::position] but with a f32 vector returned if you need that.
+    pub fn position_f32(parallax: f32, right_ascension: f32, declination: f32) -> Vec3 {
+        let distance = 1. / (parallax / 1000.);
+
+        let distnace_si = distance * (3.0856778570831 * 10_f32.powf(16.));
+
+        let right_ascension_rad = right_ascension.to_radians();
+        let declination_rad = (declination + 90.).to_radians();
+
+        let x = distnace_si * right_ascension_rad.cos() * declination_rad.sin();
+
+        let y = distnace_si * right_ascension_rad.sin() * declination_rad.sin();
+
+        let z = distnace_si * declination_rad.cos();
+
+        Vec3::new(x, y, z)
+    }
+
     /// Position on the surface of a sphere with radius in meters.
     pub fn position_surface(radius: f64, right_ascension: f64, declination: f64) -> DVec3 {
         let right_ascension_rad = right_ascension.to_radians();
@@ -365,14 +384,13 @@ pub mod velocity {
 /// Set of common functions used by `spv-rs` exposed if you want to used them for your own calculations.
 pub mod common {
     use super::coordinate_transforms::euler_angle_transformations;
-    use super::position::companion_relative_position;
+    use super::position::companion_relative_position; 
     use super::velocity::companion_relative_velocity;
     use glam::f64::DVec3;
 
     /// Takes a in as (arcseconds) and parllax in mas (milliarcsecond) and outputs a in au.
     pub fn a_to_au(parallax: f64, a: f64) -> f64 {
-        let distance_parsec = 1. / (parallax / 1000.);
-        a * distance_parsec * 149597870.7
+        a * parallax_to_parsec(parallax)
     }
 
     /// Calculates total declination in degrees with declination_degree, declination_min and declination_s in degrees, minutes and seconds respectively.
@@ -397,23 +415,24 @@ pub mod common {
 
     /// Calculates r min or the minimum distance between the primary and companion boides in a twobody system also known as perigee
     /// (suffix may change depending on what object it reffers to).
-    /// Output is just the x coordinate in the ellipses plane.
+    /// Output is just the x coordinate in the ellipses plane in au.
     pub fn perigee(a: f64, e: f64) -> f64 {
         a * (1. - e)
     }
 
     /// Calculates r max or the maximum distance between the primary and companion boides in a twobody system also known as apogee
     /// (suffix may change depending on what object it reffers to).
-    /// Output is just the x coordinate in the ellipses plane.
+    /// Output is just the x coordinate in the ellipses plane in au.
     pub fn apogee(a: f64, e: f64) -> f64 {
         a * (1. + e)
     }
 
     /// Calculates r min or the minimum distance between the primary and companion boides in a twobody system also known as perigee
     /// (suffix may change depending on what object it reffers to).
-    /// Output is 3-dimensional vector that represents the coordinates for perigee rotated to be relative to the earth/sun plane.
+    /// Output is 3-dimensional vector that represents the coordinates for perigee rotated to be relative to the earth/sun plane in meters.
     pub fn relative_perigee(a: f64, e: f64, lotn: f64, aop: f64, i: f64) -> DVec3 {
-        let x = a * (1. - e);
+        let a_si = au_to_m(a);
+        let x = a_si * (1. - e);
 
         let euler_angle_transformations = euler_angle_transformations(lotn, aop, i).to_cols_array();
         let x1 = euler_angle_transformations[0];
@@ -425,9 +444,10 @@ pub mod common {
 
     /// Calculates r max or the maximum distance between the primary and companion boides in a twobody system also known as apogee
     /// (suffix may change depending on what object it reffers to).
-    /// Output is 3-dimensional vector that represents the coordinates for apogee rotated to be relative to the earth/sun plane.
+    /// Output is 3-dimensional vector that represents the coordinates for apogee rotated to be relative to the earth/sun plane in meters.
     pub fn relative_apogee(a: f64, e: f64, lotn: f64, aop: f64, i: f64) -> DVec3 {
-        let x = a * (1. + e);
+        let a_si = au_to_m(a);
+        let x = a_si * (1. + e);
 
         let euler_angle_transformations = euler_angle_transformations(lotn, aop, i).to_cols_array();
         let x1 = euler_angle_transformations[0];
@@ -487,17 +507,17 @@ pub mod common {
             .to_degrees()
     }
 
-    /// Calculates the semi parameter for a twobody system
+    /// Calculates the semi parameter for a twobody system and returns it in meters.
     pub fn semi_parameter(a: f64, e: f64) -> f64 {
-        let a_si = a * 1000.;
+        let a_si = au_to_m(a);
         let b_si = semi_minor_axis(a, e);
 
         (b_si.powf(2.)) / a_si
     }
 
-    /// Calculates the semi minor axis for a twobody system
+    /// Calculates the semi minor axis for a twobody system and returns it in meters.
     pub fn semi_minor_axis(a: f64, e: f64) -> f64 {
-        let a_si = a * 1000.;
+        let a_si = au_to_m(a);
 
         a_si * ((1. - e.powf(2.)).sqrt())
     }
@@ -536,7 +556,7 @@ pub mod common {
 
     /// Calculates the stadard gravitational parameter
     pub fn standard_gravitational_parameter(a: f64, e: f64) -> f64 {
-        let a_si = a * 1000.;
+        let a_si = au_to_m(a);
         let p_si = semi_parameter(a, e);
 
         ((a_si.powf(3.)) * 4. * (std::f64::consts::PI.powf(2.))) / (p_si.powf(2.))
@@ -544,16 +564,18 @@ pub mod common {
 
     /// Specific mechanical energy (used by other equation but exposed here if you need it)
     pub fn specific_mechanical_energy(a: f64, e: f64) -> f64 {
+        let a_si = au_to_m(a);
         let mu = standard_gravitational_parameter(a, e);
 
-        0. - (mu / (2. * a))
+        0. - (mu / (2. * a_si))
     }
 
     /// If you dind't have the period already
     pub fn period(a: f64, e: f64) -> f64 {
+        let a_si = au_to_m(a);
         let mu = standard_gravitational_parameter(a, e);
 
-        2. * std::f64::consts::PI * (((a.powf(3.)) / mu).sqrt())
+        2. * std::f64::consts::PI * (((a_si.powf(3.)) / mu).sqrt())
     }
 
     /// If you for some reason had these parameters and not a then here ya go
@@ -566,9 +588,10 @@ pub mod common {
 
     /// Mean motion or n
     pub fn mean_motion(a: f64, e: f64) -> f64 {
+        let a_si = au_to_m(a);
         let mu = standard_gravitational_parameter(a, e);
 
-        (mu / (a.powf(3.))).sqrt()
+        (mu / (a_si.powf(3.))).sqrt()
     }
 
     /// If you for some reason had these parameters and not e then here ya go.
@@ -582,16 +605,27 @@ pub mod common {
         .sqrt()
     }
 
-    /// Distance between one foci and the center of the ellipse.
+    /// Distance between one foci and the center of the ellipse in au.
     pub fn linear_eccentricity(a: f64, e: f64) -> f64 {
         a * e
     }
 
     /// Flattening is another way to defining eccentricity for an ellipse.
     pub fn flattening(a: f64, e: f64) -> f64 {
-        let b = semi_minor_axis(a, e);
+        let a_si = au_to_m(a);
+        let b = semi_minor_axis(a_si, e);
 
-        (a - b) / a
+        (a_si - b) / a_si
+    }
+
+    /// Parallax to parsec convert function where the parallax parameter is in mas (milliarcseconds).
+    pub fn parallax_to_parsec(parallax: f64) -> f64 {
+        1. / (parallax / 1000.)
+    }
+
+    /// Simple function motsly used by `spv-rs` to convert au to meters (used for semi major-axis in most cases but can be used for other stuff too).
+    pub fn au_to_m(a: f64) -> f64 {
+        a * 1000. * 149597870.7
     }
 }
 
